Visualizing model structure
===========================

PySB currently includes a handful of tools for visualizing the structure
of models. These can be supplemented with existing tools for visualizing
the structure of rule-based models (e.g., contact maps and influence maps
for Kappa models).

.. toctree::
   :maxdepth: 2

   render_reactions.rst
   render_species.rst
